@@ -13,10 +13,12 @@ extern void summarizematches(const file_t * restrict files)
   off_t numbytes = 0;
   int numfiles = 0;
 
+  LOUD(fprintf(stderr, "summarizematches: %p\n", files));
+
   while (files != NULL) {
     file_t *tmpfile;
 
-    if (ISFLAG(files->flags, F_HAS_DUPES)) {
+    if (ISFLAG(files->flags, FF_HAS_DUPES)) {
       numsets++;
       tmpfile = files->duplicates;
       while (tmpfile != NULL) {
