@@ -1,5 +1,4 @@
 /* jdupes (C) 2015-2023 Jody Bruchon <jody@jodybruchon.com>
-   Forked from fdupes 1.51 (C) 1999-2014 Adrian Lopez
 
    Permission is hereby granted, free of charge, to any person
    obtaining a copy of this software and associated documentation files
@@ -140,7 +139,7 @@ static const char *program_name;
 #endif
 /* Refuse to build if PATHBUF_SIZE is too small */
 #if PATHBUF_SIZE < PATH_MAX
-#error "PATHBUF_SIZE can't be less than PATH_MAX"
+#warning "PATHBUF_SIZE is less than PATH_MAX"
 #endif
 
 /* Size suffixes - this gets exported */
@@ -785,11 +784,17 @@ static int check_singlefile(file_t * const restrict newfile)
 
   /* Get file information and check for validity */
   const int i = getfilestats(newfile);
+
   if (i || newfile->size == -1) {
     LOUD(fprintf(stderr, "check_singlefile: excluding due to bad stat()\n"));
     return 1;
   }
 
+  if (!S_ISREG(newfile->mode) && !S_ISDIR(newfile->mode)) {
+    LOUD(fprintf(stderr, "check_singlefile: excluding non-regular file\n"));
+    return 1;
+  }
+
   if (!S_ISDIR(newfile->mode)) {
     /* Exclude zero-length files if requested */
     if (newfile->size == 0 && !ISFLAG(flags, F_INCLUDEEMPTY)) {
@@ -1012,6 +1017,7 @@ static void grokdir(const char * const restrict dir,
 #else
   DIR *cd;
 #endif
+  static int sf_warning = 0; /* single file warning should only appear once */
 
   if (dir == NULL || filelistp == NULL) nullptr("grokdir()");
   LOUD(fprintf(stderr, "grokdir: scanning '%s' (order %d, recurse %d)\n", dir, user_item_count, recurse));
@@ -1034,9 +1040,12 @@ static void grokdir(const char * const restrict dir,
     single = 1;
     goto add_single_file;
 #endif
-    fprintf(stderr, "\nFile specs on command line disabled in this version for safety\n");
-    fprintf(stderr, "This should be restored (and safe) in a future release\n");
-    fprintf(stderr, "See https://github.com/jbruchon/jdupes or email jody@jodybruchon.com\n");
+    if (sf_warning == 0) {
+      fprintf(stderr, "\nFile specs on command line disabled in this version for safety\n");
+      fprintf(stderr, "This should be restored (and safe) in a future release\n");
+      fprintf(stderr, "See https://github.com/jbruchon/jdupes or email jody@jodybruchon.com\n");
+      sf_warning = 1;
+    }
     return; /* Remove when single file is restored */
   }
 
@@ -1875,10 +1884,10 @@ int main(int argc, char **argv)
 #endif
 #ifndef NO_CHUNKSIZE
   static long manual_chunk_size = 0;
-#endif /* NO_CHUNKSIZE */
 #ifdef __linux__
   static struct proc_cacheinfo pci;
 #endif
+#endif /* NO_CHUNKSIZE */
 #ifdef ENABLE_DEDUPE
   static struct utsname utsname;
 #endif
@@ -1890,7 +1899,7 @@ int main(int argc, char **argv)
     { "printnull", 0, 0, '0' }, //LEGACY
     { "print-null", 0, 0, '0' },
     { "one-file-system", 0, 0, '1' },
-    { "benchmark-stop", 0, 0, '9' },
+    { "", 0, 0, '9' },
     { "nohidden", 0, 0, 'A' }, //LEGACY
     { "no-hidden", 0, 0, 'A' },
     { "dedupe", 0, 0, 'B' },
@@ -2012,9 +2021,11 @@ int main(int argc, char **argv)
       SETFLAG(flags, F_ONEFS);
       LOUD(fprintf(stderr, "opt: recursion across filesystems disabled (--one-file-system)\n");)
       break;
+#ifdef DEBUG
     case '9':
       SETFLAG(flags, F_BENCHMARKSTOP);
       break;
+#endif
     case 'A':
       SETFLAG(flags, F_EXCLUDEHIDDEN);
       break;
@@ -2208,7 +2219,6 @@ int main(int argc, char **argv)
         }
       } else printf(" none");
       printf("\nCopyright (C) 2015-2023 by Jody Bruchon and contributors\n");
-      printf("Forked from fdupes 1.51, (C) 1999-2014 Adrian Lopez and contributors\n\n");
       printf("Permission is hereby granted, free of charge, to any person obtaining a copy of\n");
       printf("this software and associated documentation files (the \"Software\"), to deal in\n");
       printf("the Software without restriction, including without limitation the rights to\n");
@@ -2366,14 +2376,16 @@ int main(int argc, char **argv)
 
 #ifndef NO_TRAVCHECK
   /* We don't need the double traversal check tree anymore */
-  travdone_free(travdone_head);
+  if (travdone_head != NULL) travdone_free(travdone_head);
 #endif /* NO_TRAVCHECK */
 
+#ifdef DEBUG
   /* Pass -9 option to exit after traversal/loading code */
   if (ISFLAG(flags, F_BENCHMARKSTOP)) {
     fprintf(stderr, "\nBenchmarking stop requested; exiting.\n");
     goto skip_all_scan_code;
   }
+#endif
 
   if (ISFLAG(flags, F_REVERSESORT)) sort_direction = -1;
   if (!ISFLAG(flags, F_HIDEPROGRESS)) fprintf(stderr, "\n");
@@ -2502,7 +2514,10 @@ skip_file_scan:
     summarizematches(files);
   }
 
+#ifdef DEBUG
 skip_all_scan_code:
+#endif
+
   string_malloc_destroy();
 
 #ifdef DEBUG
