@@ -1,8 +1,8 @@
 /* Jody Bruchon's path manipulation code library
- *
- * Copyright (C) 2014-2016 by Jody Bruchon <jody@jodybruchon.com>
- * Released under The MIT License or GNU GPL v2 (your choice)
- */
+ * See jody_paths.c for license information */
+
+/* See jody_paths.c for info about this exclusion */
+#ifndef NO_SYMLINKS
 
 #ifndef JODY_PATHS_H
 #define JODY_PATHS_H
@@ -24,3 +24,5 @@ extern int make_relative_link_name(const char * const src,
 #endif
 
 #endif /* JODY_PATHS_H */
+
+#endif /* NO_SYMLINKS */
