@@ -1,9 +1,13 @@
 /* Jody Bruchon's datetime-to-epoch conversion function
  *
- * Copyright (C) 2020-2021 by Jody Bruchon <jody@jodybruchon.com>
+ * Copyright (C) 2020-2023 by Jody Bruchon <jody@jodybruchon.com>
  * Released under The MIT License
  */
 
+/* The NO_EXTFILTER exclusion is jdupes-specific and
+ * can be removed for other projects */
+#ifndef NO_EXTFILTER
+
 #include <string.h>
 #include <sys/time.h>
 #include <time.h>
@@ -11,8 +15,13 @@
 #define REQ_NUM(a) { if (a < '0' || a > '9') return -1; }
 #define ATONUM(a,b) (a = b - '0')
 /* Fast multiplies by 100 (*64 + *32 + *4) and 10 (*8 + *2) */
-#define MUL100(a) ((a << 6) + (a << 5) + (a << 2))
-#define MUL10(a) ((a << 3) + a + a)
+#ifndef STRTOEPOCH_USE_REAL_MULTIPLY
+ #define MUL100(a) ((a << 6) + (a << 5) + (a << 2))
+ #define MUL10(a) ((a << 3) + a + a)
+#else
+ #define MUL100(a) (a * 100)
+ #define MUL10(a) (a * 10)
+#endif /* STRTOEPOCH_USE_REAL_MULTIPLY */
 
 /* Accepts date[time] strings "YYYY-MM-DD" or "YYYY-MM-DD HH:MM:SS"
  * and returns the number of seconds since the Unix Epoch a la mktime()
@@ -68,3 +77,5 @@ skip_time:
 	secs = mktime(&tm);
 	return secs;
 }
+
+#endif /* NO_EXTFILTER */
