@@ -1,6 +1,6 @@
 /* Jody Bruchon's datetime-to-epoch conversion function
  *
- * Copyright (C) 2020-2021 by Jody Bruchon <jody@jodybruchon.com>
+ * Copyright (C) 2020-2023 by Jody Bruchon <jody@jodybruchon.com>
  * Released under The MIT License
  */
 
@@ -11,7 +11,10 @@
 extern "C" {
 #endif
 
+/* See note in jody_strtoepoch.c about NO_EXTFILTER */
+#ifndef NO_EXTFILTER
 time_t strtoepoch(const char * const datetime);
+#endif /* NO_EXTFILTER */
 
 #ifdef __cplusplus
 }
