@@ -1,6 +1,6 @@
 /* Jody Bruchon's Windows Unicode helper routines
  *
- * Copyright (C) 2014-2021 by Jody Bruchon <jody@jodybruchon.com>
+ * Copyright (C) 2014-2023 by Jody Bruchon <jody@jodybruchon.com>
  * Released under The MIT License
  */
 #include "jody_win_unicode.h"
@@ -58,8 +58,6 @@ error_wc2mb:
   exit(EXIT_FAILURE);
 }
 
-#else
- #define slash_convert(a)
 #endif /* UNICODE */
 
 /* Print a string that is wide on Windows but normal on POSIX */
