@@ -1,7 +1,7 @@
 /*
  * Windows-native code for getting stat()-like information
  *
- * Copyright (C) 2016-2021 by Jody Bruchon <jody@jodybruchon.com>
+ * Copyright (C) 2016-2023 by Jody Bruchon <jody@jodybruchon.com>
  * Released under The MIT License
  */
 
@@ -14,7 +14,7 @@
 #include <stdint.h>
 
 /* Convert NT epoch to UNIX epoch */
-static time_t nttime_to_unixtime(const uint64_t * const restrict timestamp)
+time_t nttime_to_unixtime(const uint64_t * const restrict timestamp)
 {
 	uint64_t newstamp;
 
@@ -25,6 +25,18 @@ static time_t nttime_to_unixtime(const uint64_t * const restrict timestamp)
 	return (time_t)newstamp;
 }
 
+/* Convert UNIX epoch to NT epoch */
+time_t unixtime_to_nttime(const uint64_t * const restrict timestamp)
+{
+	uint64_t newstamp;
+
+	memcpy(&newstamp, timestamp, sizeof(uint64_t));
+	newstamp += 11644473600LL;
+	newstamp *= 10000000LL;
+	if (newstamp <= 11644473600LL) return 0;
+	return (time_t)newstamp;
+}
+
 /* Get stat()-like extra information for a file on Windows */
 int win_stat(const char * const filename, struct winstat * const restrict buf)
 {
